%global texinfo_dir %{_datadir}/texlive/texmf-dist/tex/texinfo
# perl scripts in texinfo are not installed in default perl library dirs
# no provide and requires from them.
%global __provides_exclude ^perl\\(.*Texinfo.*\\)$
%global __requires_exclude ^perl\\(.*Texinfo.*\\)$

%bcond_with tex

Summary: Tools needed to create Texinfo format documentation files
Name: texinfo
Version: 7.0.3
Release: 2%{?dist}
License: GPLv3+
Url: http://www.gnu.org/software/texinfo/
Source0: ftp://ftp.gnu.org/gnu/texinfo/texinfo-%{version}.tar.xz
# download from https://github.com/trueroad/texinfo/blob/master/contrib/fix-info-dir
Source1: fix-info-dir

Patch3000: texinfo-7.0.2-undef-val-array-ref.patch 

BuildRequires: make gcc
BuildRequires: perl-generators help2man ncurses-devel
BuildRequires: perl(Locale::Messages) perl(Unicode::EastAsianWidth) 
BuildRequires: perl(Storable) perl(Unicode::Normalize) perl(File::Copy) 
BuildRequires: perl(Text::Unidecode)  perl(Data::Dumper)

%description
Texinfo uses a single source file to produce output in a number of formats, 
both online and printed (DVI, HTML, Info, PDF, XML, etc.). This means that 
instead of writing different documents for online information and another for 
a printed manual, you need write only one document.


%package -n info
Summary: A stand-alone TTY-based reader for GNU texinfo documentation
Provides: /sbin/install-info

%description -n info
This package provides a standalone TTY-based
browser program for viewing texinfo files. The 
GNU project uses the texinfo file format for much of its
documentation.

%if %{with tex}
%package tex
Summary: Utility for formatting Texinfo documentation files using TeX
Requires: texinfo = %{version}-%{release}
Requires: tex(tex) tex(epsf.tex)
Requires(post): %{_bindir}/texconfig-sys
Requires(postun): %{_bindir}/texconfig-sys
Provides: tex-texinfo
Provides: texlive-texinfo

%description tex
The texinfo-tex package provides tools to format Texinfo documents
for printing using TeX. Texinfo is a documentation system that can 
produce both online information and printed output from a single 
source file. The GNU Project uses the Texinfo file format for most 
of its documentation.
%endif

%prep
%setup -q
mkdir contrib
install -Dpm0755 -t contrib %{SOURCE1}
%autopatch -p1

%build
%configure --with-external-Text-Unidecode \
           --with-external-libintl-perl \
           --with-external-Unicode-EastAsianWidth \
           --disable-perl-xs
%make_build

%install
mkdir -p %{buildroot}/sbin

%make_install

mkdir -p %{buildroot}%{texinfo_dir}
install -p -m644 doc/texinfo.tex doc/txi-??.tex %{buildroot}%{texinfo_dir}

mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/install-info %{buildroot}%{_sbindir}

install -p -m0755 contrib/fix-info-dir %{buildroot}%{_sbindir}

%if %{without tex}
rm -f %{buildroot}%{_bindir}/texindex
rm -f %{buildroot}%{_bindir}/texi2dvi
rm -f %{buildroot}%{_bindir}/texi2pdf
rm -f %{buildroot}%{_bindir}/pdftexi2dvi
rm -rf %{buildroot}%{texinfo_dir}/
rm -f %{buildroot}%{_mandir}/man1/texindex.1*
rm -f %{buildroot}%{_mandir}/man1/texi2dvi.1*
rm -f %{buildroot}%{_mandir}/man1/texi2pdf.1*
rm -f %{buildroot}%{_mandir}/man1/pdftexi2dvi.1*
%endif

%find_lang %{name}
%find_lang %{name}_document

%check
export ALL_TESTS=yes
%make_build check

%if %{with tex}
%post tex
%{_bindir}/texconfig-sys rehash 2> /dev/null || :

%postun tex
%{_bindir}/texconfig-sys rehash 2> /dev/null || :
%endif

%transfiletriggerin -n info -- %{_infodir}
[ -f %{_infodir}/dir ] && create_arg="" || create_arg="--create"
%{_sbindir}/fix-info-dir $create_arg %{_infodir}/dir &>/dev/null

%transfiletriggerpostun -n info -- %{_infodir}
[ -f %{_infodir}/dir ] && %{_sbindir}/fix-info-dir --delete %{_infodir}/dir &>/dev/null


%files -f %{name}.lang -f %{name}_document.lang
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_bindir}/makeinfo
%{_bindir}/texi2any
%{_bindir}/pod2texi
%{_datadir}/texinfo
%{_infodir}/texinfo*
%{_infodir}/texi2any_api.info*
%{_infodir}/texi2any_internals.info*
%{_mandir}/man1/makeinfo.1*
%{_mandir}/man5/texinfo.5*
%{_mandir}/man1/texi2any.1*
%{_mandir}/man1/pod2texi.1*

%files -n info
%license COPYING
%{_bindir}/info
%{_sbindir}/install-info
%{_sbindir}/fix-info-dir
%{_infodir}/info-stnd.info*
%{_mandir}/man1/info.1*
%{_mandir}/man1/install-info.1*
%{_mandir}/man5/info.5*
%ghost %{_infodir}/dir
%ghost %attr(644, root, root) %{_infodir}/dir.old

%if %{with tex}
%files tex
%{_bindir}/texindex
%{_bindir}/texi2dvi
%{_bindir}/texi2pdf
%{_bindir}/pdftexi2dvi
%{texinfo_dir}/
%{_mandir}/man1/texindex.1*
%{_mandir}/man1/texi2dvi.1*
%{_mandir}/man1/texi2pdf.1*
%{_mandir}/man1/pdftexi2dvi.1*
%endif

%changelog
* Fri Jul 28 2023 kianli <kianli@tencent.com> - 7.0.3-2
- Fix incorrect file data of fix-info-dir

* Fri Jul 28 2023 kianli <kianli@tencent.com> - 7.0.3-1
- Upgrade to 7.0.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.8-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.8-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 02 2022 Yi Lin <nilusyi@tencent.com> - 6.8-2
- add bcond on texinfo-tex, default is delete texinfo-tex.

* Tue Jul 26 2022 Yi Lin <nilusyi@tencent.com> - 6.8-1
- package init.
